Index: /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/tests/test_browser.py
===================================================================
--- /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/tests/test_browser.py	(revision 12526)
+++ /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/tests/test_browser.py	(revision 12527)
@@ -620,5 +620,5 @@
             '...You logged in...', self.browser.contents)
         # Admitted customer can upload a passport picture
-        self.browser.getLink("Change portrait").click()
+        self.browser.getLink("Upload files").click()
         ctrl = self.browser.getControl(name='passporteditupload')
         file_obj = open(SAMPLE_IMAGE, 'rb')
@@ -644,5 +644,5 @@
         self.browser.getLink("Edit").click()
         self.browser.getControl(name="form.email").value = 'new_email@aa.ng'
-        self.browser.getControl("Save").click()
+        self.browser.getControl("Save", index=1).click()
         self.assertMatches('...Form has been saved...',
                            self.browser.contents)
Index: /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/viewlets.py
===================================================================
--- /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/viewlets.py	(revision 12526)
+++ /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/viewlets.py	(revision 12527)
@@ -300,7 +300,7 @@
     grok.view(CustomerBaseDisplayFormPage)
     grok.require('waeup.handleCustomer')
-    icon = 'actionicon_portrait.png'
-    text = _('Change portrait')
-    target = 'change_portrait'
+    icon = 'actionicon_up.png'
+    text = _('Upload files')
+    target = 'upload_files'
 
     @property

Index: /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/browser.py
===================================================================
--- /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/browser.py	(revision 12526)
+++ /main/waeup.ikoba/trunk/src/waeup/ikoba/customers/browser.py	(revision 12527)
@@ -38,5 +38,6 @@
     IContactForm, IObjectHistory, IIkobaObject, IIkobaUtils,
     IPasswordValidator, IUserAccount,
-    VERIFIED, REJECTED, EXPIRED, CREATED, REQUESTED, APPROVED, PROVISIONALLY)
+    STARTED, VERIFIED, REJECTED, EXPIRED, CREATED, REQUESTED,
+    APPROVED, PROVISIONALLY)
 from waeup.ikoba.browser.layout import (
     IkobaPage, IkobaEditFormPage, IkobaAddFormPage, IkobaDisplayFormPage,
@@ -389,5 +390,5 @@
         return grok.AutoFields(
             self.context.form_fields_interface).omit(
-            'customer_id', 'adm_code', 'suspended')
+            'customer_id', 'suspended')
 
     def update(self):
@@ -673,4 +674,5 @@
         return
 
+# Pages for customers
 
 class CustomerFilesUploadPage(IkobaPage):
@@ -680,8 +682,8 @@
     """
     grok.context(ICustomer)
-    grok.name('change_portrait')
+    grok.name('upload_files')
     grok.require('waeup.handleCustomer')
     grok.template('filesuploadpage')
-    label = _('Change portrait')
+    label = _('Upload files')
     pnav = 4
 
@@ -689,5 +691,5 @@
         CUSTMANAGE_STATES = getUtility(
             ICustomersUtils).CUSTMANAGE_CUSTOMER_STATES
-        if self.context.customer.state not in CUSTMANAGE_STATES:
+        if self.context.state not in CUSTMANAGE_STATES:
             emit_lock_message(self)
             return
@@ -698,6 +700,4 @@
         return
 
-# Pages for customers
-
 
 class CustomerBaseEditFormPage(IkobaEditFormPage):
@@ -708,4 +708,9 @@
     grok.require('waeup.handleCustomer')
     pnav = 4
+
+    def is_requestable(self, action=None):
+        if self.context.state == STARTED:
+            return True
+        return False
 
     @property
@@ -717,5 +722,5 @@
     @property
     def form_fields(self):
-        if self.context.state in (REQUESTED, PROVISIONALLY, APPROVED):
+        if not self.is_requestable():
             return grok.AutoFields(ICustomer).select('email', 'phone')
         return grok.AutoFields(ICustomer).omit(
@@ -727,10 +732,5 @@
         return
 
-    def is_requestable(self, action=None):
-        if self.context.state in (REQUESTED, PROVISIONALLY, APPROVED):
-            return False
-        return True
-
-    @action(_('Request registration now'),
+    @action(_('Save and request registration now'),
             warning=WARNING_CUST, condition=is_requestable)
     def finalsubmit(self, **data):